<?php

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}
include_spip('inc/acs_load_vars');
include_spip('inc/acs_version');

function acs_install($action) {
	switch ($action) {
		case 'test':
			return (false !== acs_get('ACS_VERSION'));
			break;

		case 'install':
			acs_init();
			break;

		case 'uninstall':
			acs_reset_vars();
			break;
	}
}

/*
 * Initialisation des variables ACS
 */
function acs_init() {
	$theme = find_in_path('composants/def.php');
	$r = acs_load_vars($theme);
	if ($r == 'ok') {
		acs_log('acs_init() read default values from ' . $theme, _LOG_INFO_IMPORTANTE);
	}	else {
		acs_log('acs_init() read vars for ACS version ' . acs_version() . $r, _LOG_INFO_IMPORTANTE);
		echo $r;
	}

	// Installation des composants
	$keys = [];
	include_spip('inc/composant/composant_liste');
	foreach (composants_liste() as $class => $tag) {
		echo "<br />$class";
		$install_dir = find_in_path('composants/' . $class . '/install');
		if (!$install_dir) {
			continue;
		}
		// installation des images du composant
		if (is_readable($install_dir . '/IMG')) {
			$result = copy_dir($install_dir . '/IMG/', '../' . $GLOBALS['ACS_CHEMIN'] . '/');
			acs_log('acs_init(): images of ' . $class . ' installed in ' . $GLOBALS['ACS_CHEMIN'] . '/ from ' . $install_dir, _LOG_INFO_IMPORTANTE);
			echo ', images' . ($result ? '<div class="alert">' . nl2br($result) . '</div>' : '');
		}
		// lecture des mots-clefs du composant
		if (is_readable($install_dir . '/keywords/' . $class . '_keywords_' . $GLOBALS['lang'] . '.php')) {
			$keyfile = $install_dir . '/keywords/' . $class . '_keywords_' . $GLOBALS['lang'] . '.php';
		} else {
			$keyfile = $install_dir . '/keywords/' . $class . '_keywords_fr.php';
		}
		// Si on ne trouve pas de mot-clés, on passe au composant suivant
		if (!is_readable($keyfile)) {
			if (is_readable($install_dir . '/keywords/')) {
				acs_log('acs_init() : échec de lecture du fichier des mots-clefs du composant ' . $class . ' : ' . $keyfile, _LOG_INFO_IMPORTANTE);
			}
			continue;
		}
		// On lit les mots-clefs du composant
		require_once($keyfile);
		if (!is_array($keywords)) {
			acs_log('acs_init() : échec de lecture des mots-clefs du composant ' . $class .  ' depuis ' . $keyfile, _LOG_ERREUR);
			continue;
		}
		$keys = array_merge_recursive($keys, $keywords);
		echo ', ' . _T('mots_clefs');
	}

	// Installation des mots-clefs des composants
	// On teste l'existence des deux tables des mots-clefs
	$trouver_table = charger_fonction('trouver_table', 'base');
	$table_desc_groupes_mots = $trouver_table('groupes_mots');
	$table_desc_mots = $trouver_table('mots');
	if (is_array($table_desc_groupes_mots) && (is_array($table_desc_mots))) {
		// On récupère les noms des tables
		$table_groupes_mots = $table_desc_groupes_mots['table'];
		$table_mots = $table_desc_mots['table'];

		// On construit la requête SQL
		foreach ($keywords as $grtitre => $keygroup) {
			// On recupere la clef primaire
			$id_groupe = sql_getfetsel('id_groupe', $table_groupes_mots, 'titre="' . $grtitre . '"');
			if (!$id_groupe) {
				$id_groupe = sql_insertq($table_groupes_mots, [
					'titre' => $grtitre,
					'descriptif' => is_array($keygroup['descriptif']) ? $keygroup['descriptif'][0] : $keygroup['descriptif'],
					'texte' => is_array($keygroup['texte']) ? $keygroup['texte'][0] : $keygroup['texte'],
					'unseul' => is_array($keygroup['unseul']) ? $keygroup['unseul'][0] : $keygroup['unseul'],
					'obligatoire' => is_array($keygroup['obligatoire']) ? $keygroup['obligatoire'][0] : $keygroup['obligatoire'],
					'tables_liees' => is_array($keygroup['tables_liees']) ? $keygroup['tables_liees'][0] : $keygroup['tables_liees'],
					'minirezo' => is_array($keygroup['minirezo']) ? $keygroup['minirezo'][0] : $keygroup['minirezo'],
					'comite' => is_array($keygroup['comite']) ? $keygroup['comite'][0] : $keygroup['comite'],
					'forum' => is_array($keygroup['forum']) ? $keygroup['forum'][0] : $keygroup['forum'],
				]);
				// a ce stade, si l'on a pas d'id_groupe, c'est qu'il n'existait pas ET n'a pas pu etre cree
				if (!$id_groupe) {
					acs_log('acs_init(): unable to create keywords group "' . $grtitre .'": ' . sql_error(), _LOG_ERREUR);
					continue;
				}
			}
			foreach ($keygroup['mots'] as $mottitre => $mots) {
				$id_mot = sql_getfetsel('id_mot', $table_mots, 'titre="' . $mottitre . '" AND id_groupe="' . $id_groupe . '"');
				if ($id_mot) {
					continue;
				}
				if (!sql_insertq($table_mots, [
					'titre' => $mottitre,
					'descriptif' => $mots['descriptif'],
					'texte' => $mots['texte'],
					'id_groupe' => $id_groupe,
					'type' => $grtitre
				])) {
					acs_log('acs_init(): unable to create keyword "' . $mottitre . '" in group "' . $grtitre . '": ' . sql_error(), _LOG_ERREUR);
					continue;
				}
			}
		}
	}
	echo '<br />';
	// Ecrire la meta signalant la version installee
	acs_set('ACS_VERSION', acs_version());
}

// Copie recursive d'un dossier
function copy_dir($dir2copy, $dir_paste) {
	$err = '';
	// On verifie si $dir2copy existe et est un dossier
	if ($dir2copy && is_dir($dir2copy)) {
		// Si le dossier destination n'existe pas, on le cree
		if (!mkdir_recursive($dir_paste)) {
			return 'Unable to create ' . $dir_paste;
		}
		if ($dh = opendir($dir2copy)) {
			// On liste les dossiers et fichiers de $dir2copy
			while (($file = readdir($dh)) !== false) {
				if ($file[0] == '.') {
					continue;
				}
				// S'il s'agit d'un dossier accessible en écriture on relance la fonction récursive
				if (is_dir($dir2copy . $file)) {
					if (is_writable($dir_paste)) {
						$err .= copy_dir($dir2copy . $file . '/', $dir_paste . $file . '/');
					} else {
						$err .= 'Unable to create ' . $file . ' in ' . $dir_paste . "\n";
					}
				}
				// S'il sagit d'un fichier, on le copie
				elseif (!copy($dir2copy . $file, $dir_paste . $file)) {
					$err .= 'Unable to copy ' . $dir2copy . $file . ' to ' . $dir_paste . $file . "\n";
				}
			}
		// On ferme $dir2copy
		closedir($dh);
		}
	}
	return $err;
}
