<?php

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Retourne les composants et les pages du squelette qui utilisent l'instance $nic du composant $c
 * @param string $c : classe de composant
 * @param int $nic : numero d'instance
 */
function composant_infos($c, $nic) {
	include_spip('inc/composant/composants_liste');
	include_spip('inc/composant/composants_variables');
	include_spip('inc/composant/classAdminComposant');
	include_spip('inc/filtres');

	$r = '<br />';

	// On calcule la liste de toutes les instances de composants actifs
	$choix = [];
	foreach (composants_liste() as $class => $composant) {
		foreach ($composant['instances'] as $instance => $params) {
			if ($params['on'] == 'oui') {
				array_push($choix, $class . ($instance != 0 ? '-' . $instance : ''));
			}
		}
	}

	if (count($choix) == 0) {
		ajax_retour($r . '<div class="alert">' . _T('acs:config_not_found') . '</div>');
	}

	// On établit la liste de toutes les variables ACS ayant pour valeur le nom du composant $c.$nic
	$ca = [];
	foreach ($GLOBALS['meta'] as $k => $v) {
		if ((substr($k, 0, 3) == 'acs') && ($v == $c . ($nic ? '-' . $nic : ''))) {
			if (in_array($v, $choix)) {
				array_push($ca, substr($k, 3));
			}
		}
	}

	// On retourne la liste de tous les composants qui contiennent ce composant
	if (count($ca)) {
		$lv = liste_variables();
		if (is_array($lv)) {
			$r .= '<span class="onlinehelp">' . _T('acs:used_in') . '</span><br />';
			foreach ($ca as $var) {
				if (isset($lv[$var]['c'])) {
					$pc = $lv[$var]['c'];
					$pnic = $lv[$var]['nic'];
					if (acs_get('acs' . ucfirst($pc) . $pnic . 'Nom')) {
						$pnom = acs_get('acs' . ucfirst($pc) . $pnic . 'Nom');
					} else {
						$pnom = ucfirst($pc) . (isset($pnic) ? $pnic : '');
					}
					$r .= '&nbsp;&nbsp;&nbsp;<a class="nompage" href="?exec=acs&onglet=composants&composant=' . $pc . ($pnic ? '&nic=' . $pnic : '') . '" title="acs' . $var . '">' . $pnom . '</a><br />';
				}
			}
		}
	}

	// On crée une instance :
	$composant = new AdminComposant($c, $nic);

	// On cherche toutes les pages qui contiennent cette instance du composant
	$l = $composant->listePages();
	if ($l) {
		$r .= '<hr />' . $l;
	}

	$traductions = $composant->getTraductions();
	if ((count($traductions[0]) > 0) || (count($traductions[1]) > 0)) {
		$r .= '<hr /><table width="100%"><tr><td colspan="3" class="onlinehelp centre">' . ucfirst(_T('spip:afficher_trad')) . '</td></tr>';
		$r .= (count($traductions[0]) ? '<tr><td style="width:10%; vertical-align: top;" align="' . $GLOBALS['spip_lang_right'] . '"> ' . _T('acs:public') . ' </td><td>&nbsp;</td><td>' . liens_traductions($c, $traductions[0]) . '</td></tr>' : '');
		$r .= (count($traductions[1]) ? '<tr><td style="width:10%; vertical-align: top;" align="' . $GLOBALS['spip_lang_right'] . '"> ' . _T('acs:ecrire') . ' </td><td>&nbsp;</td><td>' . liens_traductions($c, $traductions[1], 'ecrire') . '</td></tr>' : '');
		$r .= '</table>';
	}

	$r .= '<hr /><div>' .
		_T('acs:require', ['class' => $composant->nom, 'version' => $composant->version]) . ' :<br />';
	// On récupère les dépendances dans un tableau ordonné
	// avec les	plugins requis d'abord, puis les composants :
	foreach ($composant->necessite['plugin'] as $nec) {
		$npr = $nec['nom'];
		$vr = $nec['compatibilite'];
		// Compatibilite avec anciennes versions
		if (isset($nec['id'])) {
			$npr = $nec['id'];
			$vr = $nec['version'];
		}
		$get_version = $npr . '_version';
		if (is_callable($get_version)) { // la fonction existe pour spip et pour acs
			$current_version = $get_version();
		} elseif ($f = chercher_filtre('info_plugin')) { // pour les plugins sans fonction plugin_version()
			if (is_callable($f)) {
				$current_version = $f($npr, 'version');
			}
		}
		if (!$current_version) {
			$current_version = '?';
		}
		$version = substr($vr, 1, -1);
		$version = explode(';', $version);
		$min_version = $version[0];
		$max_version = $version[1];
		if (version_compare($min_version, $current_version, '>')) {
			$class_span = ' class="alert"';
			$class_v = '';
		} else {
			$class_span = '';
			$class_v = 'acs_dep_ok';
		}

		$necessite .= '<li><span"' . $class_span . '">';
		if ($npr == 'spip') {
			$necessite .= _T('plugin_necessite_spip', ['version' => $min_version]);
		} else {
		$necessite .= _T('plugin_necessite_plugin', ['plugin' => '<b>' . $npr . '</b>', 'version' => $min_version]);
		}
		$necessite .= '</span> (<b class="' . $class_v . '">' . $current_version . '</b>)</li>';
	}
	foreach ($composant->necessite['composant'] as $nec) {
		$nset = $rec['set'];
		$ncr = $nec['nom'];
		$vr = $nec['compatibilite'];
		$cr = new AdminComposant($ncr);
		$current_version = $cr->version;
		if (!$current_version) {
			$current_version = '?';
		}
		$version = substr($vr, 1, -1);
		$version = explode(';', $version);
		$min_version = $version[0];
		$max_version = $version[1];
		if (version_compare($min_version, $current_version, '>')) {
			$class = 'alert';
			$class_v = '';
		}
		else {
			$class = '';
			$class_v = 'acs_dep_ok';
		}
		$necessite .= '<li><span class="' . $class . '">' .
				_T('acs:composant') . ' <a href="' . generer_url_ecrire('acs', 'onglet=composants&composant=' . $ncr) . '">' . $ncr . '</a> ' . $min_version .
				'</span>	(<b class="' . $class_v . '">' . $current_version . '</b>)</li>';
	}
	if ($necessite) {
		$r .= '<ul style="list-style-type: disc;list-style-position: inside;">' . $necessite . '</ul>';
	}
	$r .= '</div>';

	return $r;
}

function liens_traductions($c, $langs, $cadre = '') {
	foreach ($langs as $lang) {
		$url = '?exec=composant_get_trad&c=' . $c . '&trcmp=' . $lang . '&cadre=' . $cadre;
		$r .= ' <a href="#cTrad" title="' . traduire_nom_langue($lang) . '" onclick="aSqueezeNode(\'' . $url . '\',jQuery(\'#cTrad\'));" ><img src="' . _DIR_PLUGIN_ACS . 'lang/flags/' . $lang . '.gif" alt="' . $lang . '" /></a> ';
	}
	return $r;
}
